wish-engine.model


WishEngineclj/sprotocol

create-stateclj/s

(create-state this)

Create an empty, initial state for use with this engine

Create an empty, initial state for use with this engine

eval-source-formclj/s

(eval-source-form this state form)

Evaluate the given form in the context of state

Evaluate the given `form` in the context of `state`

parse-stringclj/s

(parse-string this s)

Parse s into a form that can be eval'd

Parse `s` into a form that can be eval'd
source

cljdoc builds & hosts documentation for Clojure/Script libraries