(composite & states)Given multiple IEngineStates, produce a single IEngineState that is a composite of them all
Given multiple IEngineStates, produce a single IEngineState that is a composite of them all
(plus this other)Combine another IEngineState instance with this one into a new IEngineState
Combine another IEngineState instance with this one into a new IEngineState
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |