(create-state this)Create an empty, initial state for use with this engine
Create an empty, initial state for use with this engine
(eval-source-form this state form)Evaluate the given form in the context of state
Evaluate the given `form` in the context of `state`
(parse-string this s)Parse s into a form that can be eval'd
Parse `s` into a form that can be eval'd
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |